<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kab">
<context>
    <name>AccountItem</name>
    <message>
        <source>Sync successful</source>
        <translation>التناسق ناجح</translation>
    </message>
    <message>
        <source>Network error</source>
        <translation>خطأ في الشبكة</translation>
    </message>
    <message>
        <source>Server exception</source>
        <translation>استثناء في الخادم</translation>
    </message>
    <message>
        <source>Storage full</source>
        <translation>التخزين ممتلئ</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>Local account</source>
        <translation>الحساب المحلي</translation>
    </message>
    <message>
        <source>Event types</source>
        <translation>أنواع الأحداث</translation>
    </message>
</context>
<context>
    <name>CColorPickerWidget</name>
    <message>
        <source>Color</source>
        <translation>اللون</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Sefsex</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">Sekles</translation>
    </message>
</context>
<context>
    <name>CDayMonthView</name>
    <message>
        <source>Monday</source>
        <translation type="vanished">Arim</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="vanished">Aram</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="vanished">Ahad</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="vanished">Amhad</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="vanished">Sem</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="vanished">Sed</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="vanished">Acer</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">Aseggas</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">Ayyur</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">Ass</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>القمر</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <source>New Event</source>
        <translation type="vanished">Tadyant tamaynut</translation>
    </message>
</context>
<context>
    <name>CMonthScheduleNumItem</name>
    <message>
        <source>%1 more</source>
        <translation type="vanished">Ugar n 1%</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <source>New event</source>
        <translation type="vanished">Tadyant tamaynut</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation type="vanished">Tadyant tamaynut</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">Aseggas</translation>
    </message>
</context>
<context>
    <name>CMyScheduleView</name>
    <message>
        <source>My Event</source>
        <translation type="vanished">Tadyant-iw</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">IH</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">Kkes</translation>
    </message>
    <message>
        <source>Edit</source>
        <comment>button</comment>
        <translation type="vanished">Ẓreg</translation>
    </message>
</context>
<context>
    <name>CPushButton</name>
    <message>
        <source>New event type</source>
        <translation>نوع حدث جديد</translation>
    </message>
</context>
<context>
    <name>CScheduleDlg</name>
    <message>
        <source>New Event</source>
        <translation type="vanished">Tadyant tamaynut</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation type="vanished">Ẓreg tadyant</translation>
    </message>
    <message>
        <source>End time must be greater than start time</source>
        <translation type="vanished">Akud n taggara yezmer d netta ara igerrzen ɣef wakud n tazwara</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">IH</translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="vanished">Werǧin</translation>
    </message>
    <message>
        <source>At time of event</source>
        <translation type="vanished">Deg wakud n tedyant</translation>
    </message>
    <message>
        <source>15 minutes before</source>
        <translation type="vanished">15 tesdatin send</translation>
    </message>
    <message>
        <source>30 minutes before</source>
        <translation type="vanished">30 tesdatin send</translation>
    </message>
    <message>
        <source>1 hour before</source>
        <translation type="vanished">1 usrag send</translation>
    </message>
    <message>
        <source>1 day before</source>
        <translation type="vanished">1 wass send</translation>
    </message>
    <message>
        <source>2 days before</source>
        <translation type="vanished">2 wussan send</translation>
    </message>
    <message>
        <source>1 week before</source>
        <translation type="vanished">1 dduṛt send</translation>
    </message>
    <message>
        <source>On start day (9:00 AM)</source>
        <translation type="vanished">Deg tazwara n wass (9:00 SRG)</translation>
    </message>
    <message>
        <source>time(s)</source>
        <translation type="vanished">Akud (akuden)</translation>
    </message>
    <message>
        <source>Enter a name please</source>
        <translation>الرجاء إدخال اسم</translation>
    </message>
    <message>
        <source>The name can not only contain whitespaces</source>
        <translation>الاسم لا يمكن أن يحتوي فقط على المسافات البيضاء</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="vanished">Anaw:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Aglam:</translation>
    </message>
    <message>
        <source>All Day:</source>
        <translation type="vanished">Yal ass:</translation>
    </message>
    <message>
        <source>Starts:</source>
        <translation type="vanished">Yebda</translation>
    </message>
    <message>
        <source>Ends:</source>
        <translation type="vanished">Yekfa</translation>
    </message>
    <message>
        <source>Remind Me:</source>
        <translation type="vanished">Smekti-yi-d:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation type="vanished">Ales</translation>
    </message>
    <message>
        <source>End Repeat:</source>
        <translation type="vanished">Taggara n wallus:</translation>
    </message>
    <message>
        <source>Calendar account:</source>
        <translation>حساب الجدول:</translation>
    </message>
    <message>
        <source>Calendar account</source>
        <translation>حساب الجدول</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">Anaw</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="vanished">Aglam</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation type="vanished">Meṛṛa ass</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>الوقت:</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>الوقت</translation>
    </message>
    <message>
        <source>Solar</source>
        <translation>الشمس</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>القمر</translation>
    </message>
    <message>
        <source>Starts</source>
        <translation type="vanished">Yebda</translation>
    </message>
    <message>
        <source>Ends</source>
        <translation type="vanished">Yekfa</translation>
    </message>
    <message>
        <source>Remind Me</source>
        <translation type="vanished">Smekti-yi-d</translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation type="vanished">Ales</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation type="vanished">S wass</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation type="vanished">Ussan n yimalas</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation type="vanished">S yimalas</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation type="vanished">S wayyur</translation>
    </message>
    <message>
        <source>Yearly</source>
        <translation type="vanished">S useggas</translation>
    </message>
    <message>
        <source>End Repeat</source>
        <translation type="vanished">Taggara n wallus</translation>
    </message>
    <message>
        <source>After</source>
        <translation type="vanished">Seld</translation>
    </message>
    <message>
        <source>On</source>
        <translation type="vanished">Ɣef</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Sefsex</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">Sekles</translation>
    </message>
</context>
<context>
    <name>CScheduleOperation</name>
    <message>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation type="vanished">Meṛṛa timeḍriwin n tedyant i d-yettuɣalen ilaq ad sɛunt yiwen waddad i wass kamel.</translation>
    </message>
    <message>
        <source>Do you want to change all occurrences?</source>
        <translation type="vanished">Tebɣiḍ ad tesnefleḍ meṛṛa timeḍriwin?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Sefsex</translation>
    </message>
    <message>
        <source>Change All</source>
        <translation type="vanished">Senfel kullec</translation>
    </message>
    <message>
        <source>You are changing the repeating rule of this event.</source>
        <translation type="vanished">Tbeddleḍ alugen i d-yettuɣalen n tedyant-a.</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation type="vanished">Tekkseḍ yiwet tedyant.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation type="vanished">D tidet tebɣiḍ ad tekkseḍ tadyant-a?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">Kkes</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation type="vanished">Tebɣiḍ ad tekkseḍ meṛṛa timeḍriwin n tedyant-a neɣ tid kan i d-yettwafernen?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation type="vanished">Kkes kullec</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation type="vanished">Kkes kan tadyant-a</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation type="vanished">Tebɣiḍ ad tekkseḍ timeḍriwt-a d tid meṛṛa i d-iteddun, neɣ d tid kan i d-yettufernen?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation type="vanished">Kkes meṛṛa tidyanin i d-iteddun</translation>
    </message>
    <message>
        <source>You are changing a repeating event.</source>
        <translation type="vanished">Tbeddleḍ tadyant i d-yettuɣalen.</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation type="vanished">Tebɣiḍ ad tbeddleḍ timeḍriwt-agi kan  n tedyant, neɣ meṛṛa timeḍriwen?</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="vanished">Meṛṛa</translation>
    </message>
    <message>
        <source>Only This Event</source>
        <translation type="vanished">Tadyant-agi kan</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation type="vanished">Tebɣiḍ ad tbeddleḍ timeḍriwt-a n tedyant, neɣ tagi d meṛṛa timeḍriwen i d-iteddun?</translation>
    </message>
    <message>
        <source>All Future Events</source>
        <translation type="vanished">Tidyanin akk i d-iteddun</translation>
    </message>
    <message>
        <source>You have selected a leap month, and will be reminded according to the rules of the lunar calendar.</source>
        <translation>لقد اخترت شهرًا زائدًا، ولسوف تُذكَّر وفقًا للقواعد الخاصة بالGregorian calendar.</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="vanished">IH</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchDateItem</name>
    <message>
        <source>Y</source>
        <translation type="vanished">Aseggas</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">Ayyur</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">Ass</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchItem</name>
    <message>
        <source>Edit</source>
        <translation type="vanished">Ẓreg</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Kkes</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation type="vanished">Meṛṛa ass</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchView</name>
    <message>
        <source>No search results</source>
        <translation type="vanished">Ulac igmaḍ n unadi</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <source>ALL DAY</source>
        <translation type="vanished">YAL ASS</translation>
    </message>
</context>
<context>
    <name>CSettingDialog</name>
    <message>
        <source>Manual</source>
        <translation type="vanished">S ufus</translation>
    </message>
    <message>
        <source>15 mins</source>
        <translation>15 دقيقة</translation>
    </message>
    <message>
        <source>30 mins</source>
        <translation>30 دقيقة</translation>
    </message>
    <message>
        <source>1 hour</source>
        <translation>ساعة واحدة</translation>
    </message>
    <message>
        <source>24 hours</source>
        <translation>24 ساعة</translation>
    </message>
    <message>
        <source>Sync Now</source>
        <translation>التناسق الآن</translation>
    </message>
    <message>
        <source>Last sync</source>
        <translation>التناسق السابق</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="vanished">Arim</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="vanished">Acer</translation>
    </message>
    <message>
        <source>12-hour clock</source>
        <translation>الساعة بتنسيق 12 ساعة</translation>
    </message>
    <message>
        <source>24-hour clock</source>
        <translation>الساعة بتنسيق 24 ساعة</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>يوم الثلاثاء</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>يوم الأربعاء</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>يوم الخميس</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>يوم الجمعة</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>الأربعاء</translation>
    </message>
</context>
<context>
    <name>CTimeEdit</name>
    <message>
        <source>(%1 mins)</source>
        <translation>(%1 دقائق)</translation>
    </message>
    <message>
        <source>(%1 hour)</source>
        <translation>(%1 ساعة)</translation>
    </message>
    <message>
        <source>(%1 hours)</source>
        <translation>(%1 ساعات)</translation>
    </message>
</context>
<context>
    <name>CTitleWidget</name>
    <message>
        <source>Y</source>
        <translation type="vanished">Aseggas</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">Ayyur</translation>
    </message>
    <message>
        <source>W</source>
        <translation type="vanished">Imalas</translation>
    </message>
    <message>
        <source>D</source>
        <translation type="vanished">Ass</translation>
    </message>
    <message>
        <source>Search events and festivals</source>
        <translation>ابحث عن الأحداث والمعارض</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>الأحد</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>الاثنين</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>الثلاثاء</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>الأربعاء</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>الخميس</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>الجمعة</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>السبت</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <source>Week</source>
        <translation type="vanished">Dduṛt</translation>
    </message>
    <message>
        <source>Y</source>
        <translation type="vanished">Aseggas</translation>
    </message>
</context>
<context>
    <name>CYearScheduleView</name>
    <message>
        <source>All Day</source>
        <translation type="vanished">Meṛṛa ass</translation>
    </message>
    <message>
        <source>No event</source>
        <translation type="vanished">Ulac tadyant</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <source>Y</source>
        <translation type="vanished">Aseggas</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <source>Calendar</source>
        <translation type="vanished">Awitay</translation>
    </message>
    <message>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation type="vanished">Awitay d afecku i uskan n wazemz akked daɣen d aɣawas n yal ass i usɣiwes n wayen akk ara tgeḍ deg tudert.</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <source>Calendar</source>
        <translation type="vanished">Awitay</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation>الإدارة</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation type="vanished">Tasertit n tbaḍnit</translation>
    </message>
    <message>
        <source>Syncing...</source>
        <translation type="vanished">Amtawi...</translation>
    </message>
    <message>
        <source>Sync successful</source>
        <translation>تم التزامن بنجاح</translation>
    </message>
    <message>
        <source>Sync failed, please try later</source>
        <translation>فشل التزامن، يرجى المحاولة لاحقًا</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <source>All Day</source>
        <translation type="vanished">Yal ass</translation>
    </message>
</context>
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Amahil</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Tudert</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Wayeḍ</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Mdel</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Yiwen wass send beddu</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Smekti-yi-d azekka</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Smekti-yi-d ticki</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>بعد 15 دقيقة</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>بعد ساعة</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>بعد 4 ساعات</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Azekka</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Asmekti s usɣiwes</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 ɣer %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Ass-a</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <source>Edit</source>
        <translation type="vanished">Ẓreg</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Kkes</translation>
    </message>
    <message>
        <source>New event</source>
        <translation type="vanished">Tadyant tamaynut</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation type="vanished">Tadyant tamaynut</translation>
    </message>
</context>
<context>
    <name>JobTypeListView</name>
    <message>
        <source>You are deleting an event type.</source>
        <translation>أنت تقوم بحذف نوع حدث.</translation>
    </message>
    <message>
        <source>All events under this type will be deleted and cannot be recovered.</source>
        <translation>سيتم حذف جميع الأحداث المرتبطة بهذا النوع ولا يمكن استعادتها.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Sefsex</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="vanished">Kkes</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Account settings</source>
        <translation>إعدادات الحساب</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>الحساب</translation>
    </message>
    <message>
        <source>Select items to be synced</source>
        <translation>اختر العناصر التي سيتم تزامنها</translation>
    </message>
    <message>
        <source>Events</source>
        <translation>الأحداث</translation>
    </message>
    <message>
        <source>General settings</source>
        <translation>الإعدادات العامة</translation>
    </message>
    <message>
        <source>Sync interval</source>
        <translation>فترة التزامن</translation>
    </message>
    <message>
        <source>Manage calendar</source>
        <translation>إدارة التقويم</translation>
    </message>
    <message>
        <source>Calendar account</source>
        <translation>حساب التقويم</translation>
    </message>
    <message>
        <source>Event types</source>
        <translation>أنواع الأحداث</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Amatu</translation>
    </message>
    <message>
        <source>First day of week</source>
        <translation>أول يوم من الأسبوع</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>أوقات</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="vanished">Ass-a</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="vanished">Ass-a</translation>
    </message>
</context>
<context>
    <name>ScheduleTypeEditDlg</name>
    <message>
        <source>New event type</source>
        <translation>نوع حدث جديد</translation>
    </message>
    <message>
        <source>Edit event type</source>
        <translation>تحرير نوع الحدث</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="vanished">Isem:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>اللون:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="vanished">Sefsex</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation type="vanished">Sekles</translation>
    </message>
    <message>
        <source>The name can not only contain whitespaces</source>
        <translation>الاسم لا يمكن أن يحتوي فقط على مسافات بيضاء</translation>
    </message>
    <message>
        <source>Enter a name please</source>
        <translation>الرجاء إدخال اسم</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation type="vanished">Tallalt</translation>
    </message>
    <message>
        <source>Delete event</source>
        <translation type="vanished">Kkes tadyant</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Nɣel</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="vanished">Gzem</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="vanished">Senteḍ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Kkes</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation type="vanished">Fren kullec</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Y</source>
        <translation type="vanished">Aseggas</translation>
    </message>
    <message>
        <source>M</source>
        <translation type="vanished">Ayyur</translation>
    </message>
</context>
<context>
    <name>TimeJumpDialog</name>
    <message>
        <source>Go</source>
        <comment>button</comment>
        <translation>اذهب</translation>
    </message>
</context>
<context>
    <name>UserloginWidget</name>
    <message>
        <source>Sign In</source>
        <comment>button</comment>
        <translation type="vanished">Kcem</translation>
    </message>
    <message>
        <source>Sign Out</source>
        <comment>button</comment>
        <translation type="vanished">Ffeɣ</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <source>Y</source>
        <translation type="vanished">Aseggas</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="vanished">Ass-a</translation>
    </message>
</context>
</TS>
